'use client'
import { ChevronDownIcon, ChevronUpIcon } from "@chakra-ui/icons";
import { Avatar, Box, Button, Fade, Flex, Text } from "@chakra-ui/react";
import { useRouter } from "next/navigation";
import { memo } from "react";
import { CardListProps } from "./card-list";
import { BsEye } from "react-icons/bs";
import moment from "moment";

const ConsumerCard = ({ consumer, isOpen, onToggle }: { consumer: CardListProps, isOpen: boolean, onToggle: () => void}) => {
    const router = useRouter();

    return (
        <Box key={consumer.meter_no} border='1px' p={3} rounded={20} mt={'30px'}>
            <Flex alignItems="center" w="100%" gap={2} cursor="pointer">
                <Avatar name={consumer?.full_name} size="sm" />
                <Text fontSize="lg" fontWeight="bold" textTransform='uppercase' onClick={onToggle}>
                    {consumer?.full_name}
                </Text>
                <Box
                    onClick={() => {
                        router.push(`/officer/kycs/${consumer?.id}`);
                    }}
                >
                    <BsEye width="20px" height="20px" />
                </Box>
                <Box ms="auto" onClick={onToggle}>
                    {isOpen ? <ChevronUpIcon w="20px" h="20px" /> : <ChevronDownIcon w="20px" h="20px" />}
                </Box>
            </Flex>
            {isOpen && (
                <Fade in={isOpen}>
                    <Box mt={3} p={2} rounded="md">
                        <Flex rowGap={1} alignItems="center" flexWrap="wrap" justifyContent="space-between">
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Contact Info: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.contact_information}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Address: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.address}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    GIS Tagging: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.gis_tagging}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Contract No / Consumer No: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.contract_no_or_consumer_no}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Meter No: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.meter_no}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Additional Meter Requirement: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.additional_meter ? "Planned" : "Un-Planned"}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Premises In Use: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.premises_in_use == 1 ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Meter Exist On Site: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.meter_exist_on_site == 1 ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Premises Type: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.premises_type}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Property Type: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.property_type}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Meter Installed: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.meters_installed ? "Yes" : "No"}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Additional Meter Req: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.additional_meter_req == 1 ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Additional Meter Applied: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {consumer?.additional_meter_applied == 1 ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold">
                                    Created At: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {moment(consumer?.created_at).fromNow()}
                                    </Text>
                                </Text>
                            </Box>
                        </Flex>
                    </Box>
                </Fade >
            )}
        </Box >
    );
};

export default memo(ConsumerCard);